"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.appGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const eslint_1 = require("@nx/eslint");
const vite_1 = require("@nx/vite");
const js_1 = require("@nx/js");
const add_common_qwik_dependencies_1 = require("../../utils/add-common-qwik-dependencies");
const add_styled_dependencies_1 = require("../../utils/add-styled-dependencies");
const configure_eslint_1 = require("../../utils/configure-eslint");
const setup_tailwind_1 = require("../setup-tailwind/setup-tailwind");
const get_qwik_application_project_params_1 = require("./utils/get-qwik-application-project-params");
const normalize_options_1 = require("./utils/normalize-options");
const add_e2e_1 = require("./utils/add-e2e");
function addFiles(tree, options) {
    const templateOptions = Object.assign(Object.assign(Object.assign({}, options), (0, devkit_1.names)(options.name)), { template: '' });
    (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files'), options.projectRoot, templateOptions);
}
function appGenerator(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = yield (0, normalize_options_1.normalizeOptions)(tree, options);
        const tasks = [];
        const targets = (0, get_qwik_application_project_params_1.getQwikApplicationProjectTargets)(normalizedOptions);
        if (!normalizedOptions.setupVitest) {
            delete targets['test'];
        }
        yield (0, js_1.initGenerator)(tree, {
            skipFormat: true,
        });
        (0, devkit_1.addProjectConfiguration)(tree, normalizedOptions.projectName, {
            root: normalizedOptions.projectRoot,
            name: normalizedOptions.projectName,
            projectType: 'application',
            sourceRoot: `${normalizedOptions.projectRoot}/src`,
            targets,
            tags: normalizedOptions.parsedTags,
        });
        addFiles(tree, normalizedOptions);
        tasks.push(yield (0, vite_1.initGenerator)(tree, {
            includeLib: false,
            uiFramework: 'none',
            testEnvironment: 'node',
        }));
        if (normalizedOptions.linter === eslint_1.Linter.EsLint) {
            tasks.push((0, configure_eslint_1.configureEslint)(tree, normalizedOptions.projectName, true));
        }
        if (normalizedOptions.styleExtension) {
            tasks.push((0, add_styled_dependencies_1.addStyledModuleDependencies)(tree, normalizedOptions.styleExtension));
        }
        tasks.push((0, add_common_qwik_dependencies_1.addCommonQwikDependencies)(tree));
        if (normalizedOptions.e2eTestRunner &&
            normalizedOptions.e2eTestRunner !== 'none') {
            const e2eProjectTask = yield (0, add_e2e_1.addE2eProject)(tree, normalizedOptions);
            tasks.push(e2eProjectTask);
        }
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
        if (options.tailwind) {
            const twOptions = {
                project: normalizedOptions.name,
            };
            tasks.push(yield (0, setup_tailwind_1.default)(tree, twOptions));
        }
        return (0, devkit_1.runTasksInSerial)(...tasks);
    });
}
exports.appGenerator = appGenerator;
exports.default = appGenerator;
//# sourceMappingURL=generator.js.map