"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reactInAppGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const path = require("path");
const init_1 = require("../../../utils/react/init");
function normalizeOptions(tree, options) {
    var _a;
    const projectConfig = (0, devkit_1.readProjectConfiguration)(tree, options.project);
    return Object.assign(Object.assign({}, options), { installMUIExample: options.installMUIExample !== false, sourceRoot: (_a = projectConfig.sourceRoot) !== null && _a !== void 0 ? _a : projectConfig.root + '/src', projectRoot: projectConfig.root, projectType: projectConfig.projectType });
}
function addFiles(tree, normalizedOptions) {
    const filePath = normalizedOptions.installMUIExample ? 'mui' : 'demo';
    (0, devkit_1.generateFiles)(tree, path.join(__dirname, 'files', filePath), (0, devkit_1.joinPathFragments)(normalizedOptions.sourceRoot, 'routes/react'), {});
}
function reactInAppGenerator(tree, schema) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = normalizeOptions(tree, schema);
        if (normalizedOptions.projectType !== 'application') {
            throw new Error(`Only applications are supported, "${normalizedOptions.project}" is a library.`);
        }
        const demoFilePath = (0, devkit_1.joinPathFragments)(normalizedOptions.sourceRoot, 'integrations/react');
        if (tree.exists(demoFilePath)) {
            throw new Error(`Looks like react integration has already been configured for ${normalizedOptions.project}. "${demoFilePath}" already exists.`);
        }
        const initCallback = (0, init_1.reactInit)(tree, {
            demoFilePath: (0, devkit_1.joinPathFragments)(normalizedOptions.sourceRoot, 'integrations/react'),
            installMUIExample: !!normalizedOptions.installMUIExample,
            projectRoot: normalizedOptions.projectRoot,
        });
        addFiles(tree, normalizedOptions);
        if (!normalizedOptions.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
        return initCallback;
    });
}
exports.reactInAppGenerator = reactInAppGenerator;
exports.default = reactInAppGenerator;
//# sourceMappingURL=generator.js.map