"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.libraryGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const eslint_1 = require("@nx/eslint");
const js_1 = require("@nx/js");
const generator_1 = require("./../component/generator");
const configure_eslint_1 = require("../../utils/configure-eslint");
const vite_1 = require("@nx/vite");
const add_common_qwik_dependencies_1 = require("../../utils/add-common-qwik-dependencies");
const get_qwik_lib_project_params_1 = require("./utils/get-qwik-lib-project-params");
const normalize_options_1 = require("./utils/normalize-options");
const generator_2 = require("../storybook-configuration/generator");
const ensure_file_utils_1 = require("../../utils/ensure-file-utils");
function libraryGenerator(tree, schema) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const options = yield (0, normalize_options_1.normalizeOptions)(tree, schema);
        const tasks = [];
        yield (0, js_1.initGenerator)(tree, {
            skipFormat: true,
        });
        tasks.push(yield addLibrary(tree, options));
        tasks.push(yield configureVite(tree, options));
        if (options.linter === eslint_1.Linter.EsLint) {
            tasks.push((0, configure_eslint_1.configureEslint)(tree, options.projectName, true));
        }
        tasks.push((0, add_common_qwik_dependencies_1.addCommonQwikDependencies)(tree));
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
        return (0, devkit_1.runTasksInSerial)(...tasks);
    });
}
exports.libraryGenerator = libraryGenerator;
function addLibrary(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const tasks = [];
        const libGeneratorTask = yield (0, js_1.libraryGenerator)(tree, {
            name: options.name,
            directory: options.directory,
            tags: options.tags,
            linter: eslint_1.Linter.None,
            importPath: options.importPath,
            strict: options.strict,
            unitTestRunner: 'none',
            skipFormat: true,
            includeBabelRc: false,
            buildable: false,
            bundler: 'none',
            projectNameAndRootFormat: options.projectNameAndRootFormat,
        });
        tasks.push(libGeneratorTask);
        tree.delete(`${options.projectRoot}/src/lib/${options.projectName}.ts`);
        const templateOptions = Object.assign(Object.assign(Object.assign({}, options), (0, devkit_1.names)(options.projectName)), { strict: !!options.strict, rootTsConfigPath: (0, js_1.getRelativePathToRootTsConfig)(tree, options.projectRoot) });
        (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files'), options.projectRoot, templateOptions);
        (0, ensure_file_utils_1.ensureRootTsxExists)(tree, options.projectName);
        if (!options.setupVitest) {
            tree.delete(`${options.projectRoot}/tsconfig.spec.json`);
        }
        if (!options.buildable) {
            tree.delete(`${options.projectRoot}/package.json`);
            if (!options.setupVitest) {
                tree.delete(`${options.projectRoot}/vite.config.ts`);
            }
        }
        if (options.storybookConfiguration) {
            tasks.push(yield configureStorybook(tree, options));
        }
        if (options.generateComponent) {
            const componentGeneratorTask = yield (0, generator_1.default)(tree, {
                name: options.name,
                skipTests: !options.setupVitest,
                style: options.style,
                project: options.projectName,
                generateStories: options.storybookConfiguration,
                flat: true,
            });
            tasks.push(componentGeneratorTask);
        }
        return (0, devkit_1.runTasksInSerial)(...tasks);
    });
}
function configureVite(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const callback = yield (0, vite_1.initGenerator)(tree, {
            uiFramework: 'none',
            includeLib: true,
            testEnvironment: 'node',
        });
        const projectConfig = (0, devkit_1.readProjectConfiguration)(tree, options.projectName);
        projectConfig.targets = Object.assign(Object.assign({}, projectConfig.targets), (0, get_qwik_lib_project_params_1.getQwikLibProjectTargets)(options));
        (0, devkit_1.updateProjectConfiguration)(tree, options.projectName, projectConfig);
        return callback;
    });
}
function configureStorybook(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return (0, generator_2.default)(tree, {
            name: options.projectName,
        });
    });
}
exports.default = libraryGenerator;
//# sourceMappingURL=generator.js.map