"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.remoteGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const mf_beta_warning_1 = require("../../utils/mf-beta-warning");
const generator_1 = require("../application/generator");
const normalize_options_1 = require("../application/utils/normalize-options");
function remoteGenerator(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        (0, mf_beta_warning_1.addMicroFrontendBetaWarning)();
        const tasks = [];
        const appGeneratorSchema = Object.assign(Object.assign({}, options), { devServerPort: options.port, previewServerPort: options.port, skipFormat: true });
        const initTask = yield (0, generator_1.default)(tree, appGeneratorSchema);
        tasks.push(initTask);
        const normalizedSchema = yield (0, normalize_options_1.normalizeOptions)(tree, appGeneratorSchema);
        updateFiles(tree, normalizedSchema);
        if (options.host) {
            updateHostWithRemoteConfig(tree, options.host, normalizedSchema);
        }
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
        return (0, devkit_1.runTasksInSerial)(...tasks);
    });
}
exports.remoteGenerator = remoteGenerator;
exports.default = remoteGenerator;
function updateHostWithRemoteConfig(tree, hostProjectName, schema) {
    const hostConfig = (0, devkit_1.readProjectConfiguration)(tree, hostProjectName);
    const remoteConfigPath = (0, devkit_1.joinPathFragments)(hostConfig.root, 'src/config/remotes.json');
    if (tree.exists(remoteConfigPath)) {
        const config = (0, devkit_1.readJson)(tree, remoteConfigPath);
        config[schema.projectName] = `http://localhost:${schema.devServerPort}`;
        tree.write(remoteConfigPath, JSON.stringify(config));
    }
    else {
        devkit_1.logger.warn(`Could not find remote config at ${remoteConfigPath}. Did you generate this project with "qwik-nx:host"?`);
    }
}
function updateFiles(tree, schema) {
    // TODO: switch to empty preset once available
    tree.delete((0, devkit_1.joinPathFragments)(schema.projectRoot, 'src/routes/flower'));
    tree.delete((0, devkit_1.joinPathFragments)(schema.projectRoot, 'src/components/header/header.css'));
    tree.delete((0, devkit_1.joinPathFragments)(schema.projectRoot, 'src/components/header/header.tsx'));
    tree.delete((0, devkit_1.joinPathFragments)(schema.projectRoot, 'src/components/icons/qwik.tsx'));
    tree.delete((0, devkit_1.joinPathFragments)(schema.projectRoot, 'src/components/router-head/router-head.tsx'));
    (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files'), schema.projectRoot, {
        name: schema.projectName,
    });
}
//# sourceMappingURL=generator.js.map