"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const migrations_1 = require("../../utils/migrations");
const versions_1 = require("../../utils/versions");
function update(tree) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const projects = (0, devkit_1.getProjects)(tree);
        for (const [, config] of projects) {
            if ((0, migrations_1.isQwikNxProject)(config) && (0, migrations_1.hasCloudflareIntegration)(tree, config)) {
                // functions are no longer needed
                tree.delete((0, devkit_1.joinPathFragments)(config.root, 'functions/[[path]].ts'));
                yield updateCloudflarePagesEntry(tree, config);
            }
        }
    });
}
exports.default = update;
function updateCloudflarePagesEntry(tree, config) {
    var _a, _b, _c;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        (0, devkit_1.ensurePackage)('ts-morph', versions_1.tsMorphVersion);
        const tsMorph = yield Promise.resolve().then(() => require('ts-morph'));
        const filePath = (0, devkit_1.joinPathFragments)(config.root, 'src/entry.cloudflare-pages.tsx');
        const fileContent = (_a = tree.read(filePath)) === null || _a === void 0 ? void 0 : _a.toString();
        if (!fileContent) {
            return;
        }
        const project = new tsMorph.Project();
        const sourceFile = project.createSourceFile('temp.ts', fileContent);
        (_b = sourceFile.getVariableDeclaration('onRequest')) === null || _b === void 0 ? void 0 : _b.rename('fetch');
        (_c = [...sourceFile.getExportDeclarations()]
            .map((e) => e.getNamedExports())
            .flat()
            .find((n) => n.getName() === 'onRequest')) === null || _c === void 0 ? void 0 : _c.setName('fetch');
        tree.write(filePath, sourceFile.getFullText());
    });
}
//# sourceMappingURL=migrate-cloudflare-integration.js.map