"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const devkit_1 = require("@nx/devkit");
const migrations_1 = require("../../utils/migrations");
const vite_1 = require("@nx/vite");
const update_vite_config_1 = require("../../utils/update-vite-config");
function update(tree) {
    const projects = (0, devkit_1.getProjects)(tree);
    projects.forEach((config) => {
        if ((0, migrations_1.isQwikNxProject)(config)) {
            const viteConfigPath = (0, vite_1.normalizeViteConfigFilePathWithTree)(tree, config.root);
            if (!viteConfigPath) {
                return;
            }
            const viteConfig = tree.read(viteConfigPath).toString();
            if (viteConfig.includes('tsconfigFileNames')) {
                // dummy check to ensure viteConfig does not have "tsconfigFileNames" property
                // name collisions are very unlikely here so it seems fine to not run AST checks for this
                return;
            }
            const updated = (0, update_vite_config_1.updateViteConfig)(viteConfig, {
                qwikViteConfig: {
                    tsconfigFileNames: JSON.stringify(['tsconfig.app.json']),
                },
            });
            tree.write(viteConfigPath, updated);
        }
    });
}
exports.default = update;
//# sourceMappingURL=set-proper-tsconfig-path-for-qwik-vite-plugin.js.map