"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const devkit_1 = require("@nx/devkit");
function update(host) {
    const projects = (0, devkit_1.getProjects)(host);
    projects.forEach((config, name) => {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        var _j, _k;
        if (isQwikNxProject(config)) {
            // rename targets
            config.targets['build.client'] = config.targets['build'];
            config.targets['build.ssr'] = config.targets['build-ssr'];
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            delete config.targets['build-ssr'];
            if (config.targets['serveDebug']) {
                config.targets['serve.debug'] = config.targets['serveDebug'];
                delete config.targets['serveDebug'];
            }
            // add new build target
            config.targets.build = {
                executor: 'qwik-nx:build',
                options: {
                    runSequence: [`${name}:build.client`, `${name}:build.ssr`],
                    outputPath: (_a = config.targets['build.client'].options['outputPath']) !== null && _a !== void 0 ? _a : `dist/${config.root}`,
                },
                configurations: { preview: {} },
            };
            // update buildTarget for the serve target and its configurations
            const serveTarget = config.targets['serve'];
            if (serveTarget) {
                // using "split" because target can be specified w\ or w\o configuration
                serveTarget.options['buildTarget'] = (_b = config.targets['serve'].options['buildTarget']) === null || _b === void 0 ? void 0 : _b.split(':').map((part) => (part === 'build' ? 'build.client' : part)).join(':');
                Object.keys((_c = serveTarget.configurations) !== null && _c !== void 0 ? _c : {}).forEach((configurationName) => {
                    var _a;
                    const cfg = serveTarget.configurations[configurationName];
                    cfg.buildTarget = (_a = cfg.buildTarget) === null || _a === void 0 ? void 0 : _a.split(':').map((part) => (part === 'build' ? 'build.client' : part)).join(':');
                });
            }
            // update dependsOn
            config.targets['build.ssr'].dependsOn = (_d = config.targets['build.ssr'].dependsOn) === null || _d === void 0 ? void 0 : _d.filter((target) => target !== 'build');
            config.targets['preview'].dependsOn = (_e = config.targets['preview'].dependsOn) === null || _e === void 0 ? void 0 : _e.map((target) => (target === 'build-ssr' ? 'build' : target));
            // update intermediate target for cloudflare if it exists
            const cfTargetOptions = (_f = config.targets['build-ssr-cloudflare-pages']) === null || _f === void 0 ? void 0 : _f.options;
            if (cfTargetOptions === null || cfTargetOptions === void 0 ? void 0 : cfTargetOptions.command) {
                cfTargetOptions.command = cfTargetOptions.command.replace('build-ssr:cloudflare-pages', 'build:cloudflare-pages');
                // add configuration in the build command for cloudflare pages if it does not exist
                (_h = (_k = ((_g = (_j = config.targets.build).configurations) !== null && _g !== void 0 ? _g : (_j.configurations = {})))['cloudflare-pages']) !== null && _h !== void 0 ? _h : (_k['cloudflare-pages'] = {});
            }
            (0, devkit_1.updateProjectConfiguration)(host, name, config);
        }
    });
}
exports.default = update;
function isQwikNxProject(config) {
    var _a, _b, _c;
    if (((_b = (_a = config.targets) === null || _a === void 0 ? void 0 : _a['build']) === null || _b === void 0 ? void 0 : _b.executor) !== '@nx/vite:build') {
        return false;
    }
    if (((_c = config.targets['build-ssr']) === null || _c === void 0 ? void 0 : _c.executor) !== '@nx/vite:build') {
        return false;
    }
    if (!config.targets['preview']) {
        return false;
    }
    return true;
}
//# sourceMappingURL=switch-to-qwik-nx-build-executor.js.map