"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const path_1 = require("path");
const typescript_1 = require("typescript");
const versions_1 = require("../../utils/versions");
function update(tree) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        (0, devkit_1.ensurePackage)('ts-morph', versions_1.tsMorphVersion);
        const tsMorph = yield Promise.resolve().then(() => require('ts-morph'));
        for (const [, definition] of (0, devkit_1.getProjects)(tree)) {
            (0, devkit_1.visitNotIgnoredFiles)(tree, definition.root, (file) => {
                if ((0, path_1.extname)(file) === '.tsx') {
                    updateNamedImport(tree, tsMorph, file, '@builder.io/qwik', 'useClientEffect$', 'useVisibleTask$');
                }
            });
        }
    });
}
exports.default = update;
function updateNamedImport(tree, tsMorph, filePath, importModuleSpecifier, importName, updatedImportName) {
    const fileContent = tree.read(filePath).toString();
    const project = new tsMorph.Project();
    const sourceFile = project.createSourceFile('temp.ts', fileContent);
    const imports = sourceFile.getImportDeclarations();
    const relevantImports = imports
        .map((imp) => {
        const moduleSpecifier = imp.getModuleSpecifierValue();
        if (moduleSpecifier !== importModuleSpecifier) {
            return [];
        }
        return imp
            .getNamedImports()
            .filter((namedImport) => namedImport.getName() === importName);
    })
        .filter((imports) => imports.length)
        .flat();
    if (relevantImports.length > 0) {
        relevantImports.forEach((imp) => imp.replaceWithText(updatedImportName));
        sourceFile.forEachDescendant((node) => {
            var _a;
            if (node.getKind() === typescript_1.SyntaxKind.Identifier &&
                node.getText() === importName &&
                [typescript_1.SyntaxKind.CallExpression, typescript_1.SyntaxKind.VariableDeclaration].includes((_a = node.getParent()) === null || _a === void 0 ? void 0 : _a.getKind())) {
                node.replaceWithText(updatedImportName);
            }
        });
        tree.write(filePath, sourceFile.getFullText());
    }
    return tree;
}
//# sourceMappingURL=update-use-client-effect$-to-use-visisble-task$.js.map