"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withNx = void 0;
const vite_1 = require("vite");
const optimizer_1 = require("@builder.io/qwik/optimizer");
/**
 * Updates config for the storybook
 * @param config vite configuration to be updated for storybook
 * @param qwikViteOpts options for the `qwikVite` plugin that is being overridden in this utility
 */
function withNx(config, qwikViteOpts) {
    var _a;
    const updated = (0, vite_1.mergeConfig)(config, {
        build: {
            rollupOptions: {
                external: ['@qwik-city-sw-register'],
            },
        },
    });
    updated.plugins = (_a = updated.plugins) === null || _a === void 0 ? void 0 : _a.flat(10).map((plugin) => {
        switch (plugin === null || plugin === void 0 ? void 0 : plugin.name) {
            case 'vite-plugin-qwik':
                // as of now there's no way of extending qwikVite with overridden output paths, thus have to override to completely
                return (0, optimizer_1.qwikVite)(qwikViteOpts);
            case 'vite-plugin-qwik-city':
                // logic below has been copied from "storybook-framework-qwik" plugin
                // it doesn't work out of the box for Nx applications because base config is not included by storybook if it's not in the root cwd
                // Qwik-city plugin may be used in apps, but it has mdx stuff that conflicts with Storybook mdx
                // we'll try to only remove the transform code (where the mdx stuff is), and keep everything else.
                return Object.assign(Object.assign({}, plugin), { transform: () => null });
            default:
                return plugin;
        }
    });
    return updated;
}
exports.withNx = withNx;
//# sourceMappingURL=storybook.js.map